summaryrefslogtreecommitdiffstats
path: root/drivers/staging/vt6656/usbpipe.c
diff options
context:
space:
mode:
authorMalcolm Priestley2014-05-26 14:59:03 +0200
committerGreg Kroah-Hartman2014-05-26 19:36:49 +0200
commit285d58c486a1b0921a10730772b64e38cb06ae54 (patch)
tree9a961a49f33eeaec0c56d099b4fef922f5f8b08d /drivers/staging/vt6656/usbpipe.c
parentstaging: vt6656: rename PIPEnsControlIn/CONTROLnsRequestIn with vnt_control_in (diff)
downloadkernel-qcow2-linux-285d58c486a1b0921a10730772b64e38cb06ae54.tar.gz
kernel-qcow2-linux-285d58c486a1b0921a10730772b64e38cb06ae54.tar.xz
kernel-qcow2-linux-285d58c486a1b0921a10730772b64e38cb06ae54.zip
staging: vt6656: replace ControlvWriteByte with vnt_control_out_u8
add new function in usbpipe.c to replace ControlvWriteByte Signed-off-by: Malcolm Priestley <tvboxspy@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/vt6656/usbpipe.c')
-rw-r--r--drivers/staging/vt6656/usbpipe.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/drivers/staging/vt6656/usbpipe.c b/drivers/staging/vt6656/usbpipe.c
index 7d4e131303de..2264c8c7ec7e 100644
--- a/drivers/staging/vt6656/usbpipe.c
+++ b/drivers/staging/vt6656/usbpipe.c
@@ -28,7 +28,7 @@
* Functions:
* vnt_control_out - Write variable length bytes to MEM/BB/MAC/EEPROM
* vnt_control_in - Read variable length bytes from MEM/BB/MAC/EEPROM
* ControlvWriteByte - Write one byte to MEM/BB/MAC/EEPROM
* ControlvReadByte - Read one byte from MEM/BB/MAC/EEPROM
* ControlvMaskByte - Read one byte from MEM/BB/MAC/EEPROM and clear/set some bits in the same address
*
@@ -83,6 +83,12 @@ int vnt_control_out(struct vnt_private *priv, u8 request, u16 value,
return STATUS_SUCCESS;
}
+void vnt_control_out_u8(struct vnt_private *priv, u8 reg, u8 reg_off, u8 data)
+{
+ vnt_control_out(priv, MESSAGE_TYPE_WRITE,
+ reg_off, reg, sizeof(u8), &data);
+}
+
int vnt_control_in(struct vnt_private *priv, u8 request, u16 value,
u16 index, u16 length, u8 *buffer)
{
@@ -28,7 +28,7 @@
* vnt_control_out - Write variable length bytes to MEM/BB/MAC/EEPROM
* vnt_control_in - Read variable length bytes from MEM/BB/MAC/EEPROM
- * ControlvWriteByte - Write one byte to MEM/BB/MAC/EEPROM
+ * vnt_control_out_u8 - Write one byte to MEM/BB/MAC/EEPROM
* ControlvReadByte - Read one byte from MEM/BB/MAC/EEPROM
* ControlvMaskByte - Read one byte from MEM/BB/MAC/EEPROM and clear/set some bits in the same address